Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func CheckIfClone ¶
CheckIfClone checks if a clone of this exe is running
func CloneWithLockFile ¶
CloneWithLockFile exits when a new clone of this exe creates a new lock file at lockPath On startup, new clones create a lock file and then wait for 2 seconds for other clones to exit Once running, the exe checks for a lock file every second and exits if a lock file exists
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.